@@ -77,11 +77,11 @@ class HiveParamEscaper(ParamEscaper):
             item = item.decode('utf-8')
         return "'{}'".format(
             item
-                .replace('\\', '\\\\')
-                .replace("'", "\\'")
-                .replace('\r', '\\r')
-                .replace('\n', '\\n')
-                .replace('\t', '\\t')
+            .replace('\\', '\\\\')
+            .replace("'", "\\'")
+            .replace('\r', '\\r')
+            .replace('\n', '\\n')
+            .replace('\t', '\\t')
         )
 
 
@@ -207,7 +207,6 @@ class Cursor(DBAPICursor):
         self._query_id = None
         self._batch = list()
         self._rowcount = 0
-        self._iter_index = 0
 
     def _reset_state(self):
         """Reset state about the previous query in preparation for running another query"""
@@ -350,19 +349,17 @@ class Cursor(DBAPICursor):
             self._data = list()
         while len(self._data) < size:
             _logger.info("fetching next batch from fetch many")
-            _logger.info(len(self._data))
-            _logger.info("no  of rows accumulated {}".format(self.rows_count))
             rows = self.fetch_batch()
-            if rows is None:
+            if rows is None or len(rows) == 0:
                 break
-            self.rows_count = self.rows_count + len(rows)
-            print(self.rows_count)
             self._data += rows
         _logger.info(len(self._data))
         if len(self._data) == size:
-            return self._data
-        rows = self._data[self._iter_index:self._iter_index+size]
-        self._iter_index = size
+            rows = self._data
+            self._data = None
+            return rows
+        rows = self._data[0:size]
+        self._data = None
         return rows
 
     def fetchone(self):
@@ -417,8 +414,10 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("select * from date_dim;")
-    bdata = cursor.fetchall()
+    cursor.execute("select * from call_center limit 3;")
+    bdata = []
+    for i in range(10):
+        bdata += cursor.fetchmany()
     try:
         # if len(bdata) < 1000:
         for row in bdata:
